@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.43';
+our $VERSION = '1.00';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -383,8 +383,6 @@ calendars, checkerboard patterns, games such as sudoku, banners and mazes,
 and create animations of cell values and backgrounds via supplied jQuery.
 Rewrap existing tables from Excel, HTML, JSON, CSV and YAML files.
 
-THIS MODULE IS AN ALPHA RELEASE! Although we are very close to BETA.
-
 =head1 CLI TOOLS
 
 =over 4
@@ -923,11 +921,6 @@ their output, if installed:
 
 Uses this module (Spreadsheet::HTML) to format SQL query results.
 
-=item * L<DBIx::XHTML_Table>
-
-My original from 2001. Can handle advanced grouping, individual cell
-value contol, rotating attributes and totals/subtotals.
-
 =item * L<http://www.w3.org/TR/html5/tabular-data.html>
 
 =item * L<http://en.wikipedia.org/wiki/Rotation_matrix>
